@@ -76,6 +76,7 @@ categories = {
     "outfits": Category("Outfits", models.Outfit, no_images=True),
     "worlds": Category("Game Worlds", models.World, no_images=True, include_deprecated=True),
     "mounts": Category("Mounts", models.Mount),
+    "updates": Category("Updates", models.Update, no_images=True),
 }
 
 
@@ -122,7 +123,7 @@ def generate(skip_images, db_name, skip_deprecated):
                         unparsed.append(titles[i])
             if unparsed:
                 click.echo(f"{Fore.RED}Could not parse {len(unparsed):,} articles.{Style.RESET_ALL}")
-                print(f"\t-> {Fore.RED}%s{Style.RESET_ALL}]" % f'{Style.RESET_ALL},{Fore.RED}'.join(unparsed))
+                print(f"\t-> {Fore.RED}{f'{Style.RESET_ALL},{Fore.RED}'.join(unparsed)}{Style.RESET_ALL}]")
             dt = (time.perf_counter() - exec_time)
             print(f"\t{Fore.GREEN}Parsed articles in {dt:.2f} seconds.{Style.RESET_ALL}")
 
@@ -140,7 +141,7 @@ def generate(skip_images, db_name, skip_deprecated):
             save_outfit_images(conn)
             save_maps(conn)
     with conn:
-        gen_time = datetime.datetime.utcnow()
+        gen_time = datetime.datetime.now(tz=datetime.timezone.utc)
         schema.DatabaseInfo.insert(conn, **{"key": "timestamp", "value": str(gen_time.timestamp())})
         schema.DatabaseInfo.insert(conn, **{"key": "generate_time", "value": str(gen_time)})
         schema.DatabaseInfo.insert(conn, **{"key": "version", "value": __version__})
@@ -192,7 +193,7 @@ def generate_loot_statistics(conn: sqlite3.Connection):
                     # We delete any duplicate record that was added from the creature's article's loot if it exists
                     c.execute("DELETE FROM creature_drop WHERE creature_id = ? AND item_id = ?",
                               (creature_id, item_id))
-                c.executemany(f"INSERT INTO creature_drop(creature_id, item_id, chance, min, max) VALUES(?,?,?,?,?)",
+                c.executemany("INSERT INTO creature_drop(creature_id, item_id, chance, min, max) VALUES(?,?,?,?,?)",
                               loot_items)
         dt = (time.perf_counter() - start_time)
         print(f"{Fore.GREEN}\tParsed loot statistics in {dt:.2f} seconds.{Style.RESET_ALL}")
@@ -215,8 +216,7 @@ def article_show(item):
 def get_cache_info(table):
     try:
         with open(f"images/{table}/cache_info.json", 'r') as f:
-            cache_info = json.load(f)
-            return cache_info
+            return json.load(f)
     except (FileNotFoundError, json.JSONDecodeError):
         return {}
 
@@ -275,7 +275,7 @@ def save_images(conn: sqlite3.Connection, key: str, value: Category):
     dt = (time.perf_counter() - start)
     if failed:
         print(f"{Style.RESET_ALL}\tCould not fetch {len(failed):,} images.{Style.RESET_ALL}")
-        print(f"\t-> {Style.RESET_ALL}%s{Style.RESET_ALL}" % f'{Style.RESET_ALL},{Style.RESET_ALL}'.join(failed))
+        print(f"\t-> {Style.RESET_ALL}{f'{Style.RESET_ALL},{Style.RESET_ALL}'.join(failed)}{Style.RESET_ALL}")
     print(f"{Fore.GREEN}\tSaved {key} images in {dt:.2f} seconds."
           f"\n\t{fetch_count:,} fetched, {cache_count:,} from cache.{Style.RESET_ALL}")
 
@@ -301,7 +301,7 @@ def save_outfit_images(conn):
         "Outfit %s Female Addon 3.gif",
     ]
     addon_sequence = (0, 1, 2, 3) * 2
-    sex_sequence = ["Male"]*4 + ["Female"]*4
+    sex_sequence = ["Male"] * 4 + ["Female"] * 4
     for article_id, name in results:
         for i, image_name in enumerate(name_templates):
             file_name = image_name % name
@@ -313,7 +313,7 @@ def save_outfit_images(conn):
     fetch_count = 0
     failed = []
     start = time.perf_counter()
-    with progress_bar(generator, f"Fetching outfit images", len(titles), item_show_func=img_show) as bar:
+    with progress_bar(generator, "Fetching outfit images", len(titles), item_show_func=img_show) as bar:
         for image in bar:
             if image is None:
                 continue
@@ -335,13 +335,13 @@ def save_outfit_images(conn):
                 failed.append(image.file_name)
                 continue
             article_id, addons, sex = image_info[image.file_name]
-            conn.execute(f"INSERT INTO outfit_image(outfit_id, addon, sex, image) VALUES(?, ?, ?, ?)",
+            conn.execute("INSERT INTO outfit_image(outfit_id, addon, sex, image) VALUES(?, ?, ?, ?)",
                          (article_id, addons, sex, image_bytes))
         save_cache_info(table, cache_info)
     dt = (time.perf_counter() - start)
     if failed:
         print(f"{Style.RESET_ALL}\tCould not fetch {len(failed):,} images.{Style.RESET_ALL}")
-        print(f"\t-> {Style.RESET_ALL}%s{Style.RESET_ALL}" % f'{Style.RESET_ALL},{Style.RESET_ALL}'.join(failed))
+        print(f"\t-> {Style.RESET_ALL}{f'{Style.RESET_ALL},{Style.RESET_ALL}'.join(failed)}{Style.RESET_ALL}")
     print(f"{Fore.GREEN}\tSaved outfit images in {dt:.2f} seconds."
           f"\n\t{fetch_count:,} fetched, {cache_count:,} from cache.{Style.RESET_ALL}")
 
@@ -361,7 +361,7 @@ def get_articles(category, data_store, key=None, include_deprecated=False):
 
 def save_maps(con):
     url = "https://tibiamaps.github.io/tibia-map-data/floor-{0:02d}-map.png"
-    os.makedirs(f"images/map", exist_ok=True)
+    os.makedirs("images/map", exist_ok=True)
     for z in range(16):
         try:
             with open(f"images/map/{z}.png", "rb") as f:
@@ -374,7 +374,7 @@ def save_maps(con):
                 f.write(image)
         except requests.HTTPError:
             continue
-        con.execute(f"INSERT INTO map(z, image) VALUES(?,?)", (z, image))
+        con.execute("INSERT INTO map(z, image) VALUES(?,?)", (z, image))
 
 
 if __name__ == "__main__":
