@@ -19,6 +19,7 @@ import urllib.parse
 import requests
 
 from tibiawikisql import __version__
+from tibiawikisql.utils import parse_attributes
 
 BASE_URL = "https://tibia.fandom.com"
 
@@ -87,6 +88,11 @@ class Article(WikiEntry):
         super().__init__(article_id, title, timestamp)
         self.content = content
 
+    @property
+    def infobox_attributes(self):
+        """:class:`dict`: Returns a mapping of the template attributes."""
+        return parse_attributes(self.content)
+
 
 class Image(WikiEntry):
     """
@@ -229,11 +235,11 @@ class WikiClient:
 
         .. warning ::
 
-            The order of the returned articles might not match the order of the provided names due to an API limitation.
+            The order of the returned images might not match the order of the provided names due to an API limitation.
 
         Parameters
         ----------
-        names: list[:class:`str`]
+        names: :class:`list` of :class:`str`
             A list of names of images to get the info of.
 
         Yields
@@ -282,7 +288,7 @@ class WikiClient:
 
         Parameters
         ----------
-        names: list[:class:`str`]
+        names: :class:`list` of :class:`str`
             A list of names of articles to get the info of.
 
         Yields
@@ -302,7 +308,7 @@ class WikiClient:
         while True:
             if i >= len(names):
                 break
-            params["titles"] = "|".join(names[i:min(i+50, len(names))])
+            params["titles"] = "|".join(names[i:min(i + 50, len(names))])
             i += 50
             r = s.get(cls.ENDPOINT, params=params)
             data = json.loads(r.text)
