@@ -161,10 +161,12 @@ class Npc(abc.Row, abc.Parseable, table=schema.Npc):
         The race of the NPC.
     job: :class:`str`
         The NPC's job.
+    job_additionals: :class:`str`
+        Other additional jobs the NPC might have, separated by commas.
     location: :class:`str`
         The location of the NPC.
     city: :class:`str`
-        The city where the NPC is located.
+        The nearest city to where the NPC is located.
     x: :class:`int`
         The x coordinates of the NPC.
     y: :class:`int`
@@ -194,6 +196,7 @@ class Npc(abc.Row, abc.Parseable, table=schema.Npc):
         "gender",
         "race",
         "job",
+        "job_additionals",
         "location",
         "city",
         "x",
@@ -227,9 +230,22 @@ class Npc(abc.Row, abc.Parseable, table=schema.Npc):
     }
     _pattern = re.compile(r"Infobox[\s_]NPC")
 
+    @property
+    def job_list(self):
+        if not self.job_additionals:
+            return [self.job] if self.job else []
+        return [self.job] + self.job_additionals.split(",")
+
     @classmethod
     def from_article(cls, article):
         npc = super().from_article(article)
+        additional_jobs = []
+        for i in range(2, 7):
+            key = f"job{i}"
+            if key in npc._raw_attributes:
+                additional_jobs.append(clean_links(npc._raw_attributes[key]))
+        if additional_jobs:
+            npc.job_additionals = ",".join(additional_jobs)
         if npc is None:
             return None
         if "buys" in npc._raw_attributes and article.title != "Minzy":
@@ -308,8 +324,8 @@ class Npc(abc.Row, abc.Parseable, table=schema.Npc):
                 sorcerer = "sorcerer" in group.lower() or npc.name == "Eliza"
                 if not(knight or paladin or druid or sorcerer):
                     def in_jobs(vocation, _npc):
-                        return vocation in (_npc.job+_npc._raw_attributes.get("job2", "") +
-                                            _npc._raw_attributes.get("job3", "")).lower()
+                        return vocation in (_npc.job + _npc._raw_attributes.get("job2", "")
+                                            + _npc._raw_attributes.get("job3", "")).lower()
 
                     knight = in_jobs("knight", npc)
                     paladin = in_jobs("paladin", npc)
@@ -432,8 +448,8 @@ class NpcSellOffer(NpcOffer, abc.Row, table=schema.NpcSelling):
 
     @classmethod
     def _get_base_query(cls):
-        return f"""SELECT {cls.table.__tablename__}.*, item.title as item_title, npc.title as npc_title, 
-                  npc.city as npc_city, currency.title as currency_title 
+        return f"""SELECT {cls.table.__tablename__}.*, item.title as item_title, npc.title as npc_title,
+                  npc.city as npc_city, currency.title as currency_title
                   FROM {cls.table.__tablename__}
                   LEFT JOIN npc ON npc.article_id = npc_id
                   LEFT JOIN item ON item.article_id = item_id
@@ -498,7 +514,7 @@ class NpcBuyOffer(NpcOffer, abc.Row, table=schema.NpcBuying):
 
     @classmethod
     def _get_base_query(cls):
-        return f"""SELECT {cls.table.__tablename__}.*, item.title as item_title, npc.title as npc_title, 
+        return f"""SELECT {cls.table.__tablename__}.*, item.title as item_title, npc.title as npc_title,
                    npc.city as npc_city, currency.title as currency_title FROM {cls.table.__tablename__}
                    LEFT JOIN npc ON npc.article_id = npc_id
                    LEFT JOIN item ON item.article_id = item_id
@@ -555,7 +571,7 @@ class NpcSpell(abc.Row, table=schema.NpcSpell):
                 attributes.append(f"{attr}={v!r}")
             except AttributeError:
                 pass
-        return "{0.__class__.__name__}({1})".format(self, ",".join(attributes))
+        return f"{self.__class__.__name__}({','.join(attributes)})"
 
     def insert(self, c):
         if getattr(self, "spell_id", None):
@@ -572,7 +588,7 @@ class NpcSpell(abc.Row, table=schema.NpcSpell):
     @classmethod
     def _get_base_query(cls):
         return f"""SELECT {cls.table.__tablename__}.*, spell.title as spell_title, npc.title as npc_title,
-                  spell.price as price, npc.city as npc_city 
+                  spell.price as price, npc.city as npc_city
                   FROM {cls.table.__tablename__}
                   LEFT JOIN npc ON npc.article_id = npc_id
                   LEFT JOIN spell ON spell.article_id = spell_id"""
